@@ -1,4 +1,4 @@
-from webob.multidict import MultiDict
+from paste.util.multidict import MultiDict
 from flanker.mime.message.headers.parsing import normalize, parse_stream
 from flanker.mime.message.headers.encoding import to_mime
 from flanker.mime.message.errors import EncodingError
@@ -64,6 +64,7 @@ class MimeHeaders(object):
         """
 
         changed = [False]
+
         def tracking_fn(key, val):
             new_key, new_val = fn(key, val)
             if new_val != val or new_key != key:
@@ -75,21 +76,18 @@ class MimeHeaders(object):
             self.v = v
             self.changed = True
 
-
     def items(self):
         """
         Returns header,val pairs in the preserved order.
         """
         return list(self.iteritems())
 
-
     def iteritems(self):
         """
         Returns iterator header,val pairs in the preserved order.
         """
         return self.v.iteritems()
 
-
     def get(self, key, default=None):
         """
         Returns header value (case-insensitive).
